import { useState, useEffect } from 'react';
import axios from 'axios';
import './LabsPage.css';

interface Data {
    // Define the structure of the data you expect from the endpoint
    id: number;
    name: string;
    // Add other fields as needed
}

export default function LabsPage() {
    const [data, setData] = useState<Data[]>([]);
    const [loading, setLoading] = useState<boolean>(true);
    const [error, setError] = useState<string | null>(null);

    useEffect(() => {
        axios.get<Data[]>('https://vtrc-backend.discovery.cs.vt.edu/api/labs')
            .then(response => {
                setData(response.data);
                setLoading(false);
            })
            .catch(error => {
                setError(error.message);
                setLoading(false);
            });
    }, []);

    if (loading) {
        return <div className='labs-page center-content'><h1>Loading...</h1></div>;
    }

    if (error) {
        return <div className='labs-page center-content'><h1>Error: {error}</h1></div>;
    }

    return (
        <div className='labs-page center-content'>
            <h1>Data from Endpoint</h1>
            <ul>
                {data.map(item => (
                    <li key={item.id}>{item.name}</li>
                ))}
            </ul>
        </div>
    );
}